.. _user_guide:

==========
User guide
==========
Welcome to the user guide of ``skchange``. This guide provides a high-level overview of
the library, its design and core concepts. It also aims to give a wide range of usage
examples.
Use the navigation bar on the left to explore the different sections of the guide.

Other resources:

* `Notebook tutorial <https://github.com/sktime/sktime-tutorial-pydata-global-2024>`_ from `PyData Global 2024 <https://pydata.org/global2024>`_


.. toctree::
    :maxdepth: 1
    :hidden:

    getting_started
    concepts/index
    interval_scores/index
    penalties/index
    change_detection/index
    anomaly_detection/index
